pub enum Error {
Show 20 variants
Io(Error),
Decode(DecodeError),
Utf8Error(FromUtf8Error),
InvalidCertType(u32),
InvalidFormat,
UnexpectedEof,
NotCertificate,
KeyTypeMismatch,
InvalidSignature,
InvalidAllowedSigner(AllowedSignerParsingError),
InvalidAllowedSigners(AllowedSignerParsingError, usize),
SigningError,
EncryptedPrivateKey,
EncryptedPrivateKeyNotSupported,
UnknownKeyType(String),
UnknownCurve(String),
ParsingError,
YubikeyPIVError(Error),
FidoError(Error),
Unsupported,
}Expand description
A type to represent the different kinds of errors.
Variants
Io(Error)
There was an error reading from or writing to an external source
Decode(DecodeError)
Data was improperly encoded as base64
Utf8Error(FromUtf8Error)
Data was not a valid UTF8 string.
InvalidCertType(u32)
A certificate type that doesn’t exist was requested. Should be either 1 or 2
InvalidFormat
The format of a certificate or data was incorrect/invalid
UnexpectedEof
The stream ended unexpectedly
NotCertificate
The provided data was not a certificate
KeyTypeMismatch
The requested signature or key was incompatible with what was previously specified or an x509 certificate contains a public key that is not compatible with SSH.
InvalidSignature
The certificate is not signed correctly and invalid
InvalidAllowedSigner(AllowedSignerParsingError)
A parsing error for one allowed signer
InvalidAllowedSigners(AllowedSignerParsingError, usize)
A parsing error for a collection/file of allowed signers
SigningError
A cryptographic operation failed.
EncryptedPrivateKey
An encrypted private key was provided with no decryption key
EncryptedPrivateKeyNotSupported
An encrypted private key was supplied but the encryption method is not supported
UnknownKeyType(String)
The key type is unknown
UnknownCurve(String)
The curve in an ECC public/private key/signature is unknown
ParsingError
A generic parsing error which occurs whenever data sent does not match the expected format
YubikeyPIVError(Error)
An error occured in the yubikey module
FidoError(Error)
An error occured in the FIDO module
Unsupported
This occurs when you try to use a feature that could technically work but is currently unimplemented.