pub struct PrivateKey {
    pub key_type: KeyType,
    pub kind: PrivateKeyKind,
    pub pubkey: PublicKey,
    pub comment: Option<String>,
}
A type which represents an OpenSSH public key.

Fields

key_type: KeyType

Key type.

kind: PrivateKeyKind

The kind of public key.

pubkey: PublicKey

The corresponding public key

comment: Option<String>

Associated comment, if any.

Implementations

Reads an OpenSSH private key from a given path and passphrase

Reads an OpenSSH private key from a given path.

Reads an OpenSSH private key from a given string and passphrase

Reads an OpenSSH private key from a given string.

Create a private key from just the decrypted private bytes