Enum sshcerts::error::Error[][src]

pub enum Error {
    Io(Error),
    Decode(DecodeError),
    Utf8Error(FromUtf8Error),
    InvalidCertType(u32),
    InvalidFormat,
    UnexpectedEof,
    NotCertificate,
    KeyTypeMismatch,
    CertificateInvalidSignature,
    SigningError,
    EncryptedPrivateKeyNotSupported,
    UnknownKeyType(String),
    UnknownCurve(String),
}

A type to represent the different kinds of errors.

Variants

Io(Error)

There was an error reading from or writing to an external source

Decode(DecodeError)

Data was improperly encoded as base64

Utf8Error(FromUtf8Error)

Data was not a valid UTF8 string.

InvalidCertType(u32)

A certificate type that doesn’t exist was requested. Should be either 1 or 2

InvalidFormat

The format of a certificate was incorrect

UnexpectedEof

The stream ended unexpectedly

NotCertificate

The provided data was not a certificate

KeyTypeMismatch

The requested signature or key was incompatible with what was previously specified

CertificateInvalidSignature

The certificate is not signed correctly and invalid

SigningError

A cryptographic operation failed.

EncryptedPrivateKeyNotSupported

An encrypted private key was supplied and is not supported

UnknownKeyType(String)

The key type is unknown

UnknownCurve(String)

The curve in an ECC public/private key/signature is unknown