Enum sshcerts::error::Error [−][src]
A type to represent the different kinds of errors.
Variants
Io(Error)There was an error reading from or writing to an external source
Decode(DecodeError)Data was improperly encoded as base64
Utf8Error(FromUtf8Error)Data was not a valid UTF8 string.
InvalidCertType(u32)A certificate type that doesn’t exist was requested. Should be either 1 or 2
The format of a certificate was incorrect
The stream ended unexpectedly
The provided data was not a certificate
The requested signature or key was incompatible with what was previously specified
The certificate is not signed correctly and invalid
A cryptographic operation failed.
An encrypted private key was supplied and is not supported
UnknownKeyType(String)The key type is unknown
UnknownCurve(String)The curve in an ECC public/private key/signature is unknown